@@ -36,6 +36,8 @@ along with ANSIFilter.  If not, see <http://www.gnu.org/licenses/>.
 
 const Arg_parser::Option options[] = {
     { 'a', "anchors",    Arg_parser::maybe },
+    { 'b', "append",     Arg_parser::no },
+    { 'n', "tee",        Arg_parser::no },
     { 'd', "doc-title",  Arg_parser::yes },
     { 'e', "encoding",   Arg_parser::yes },
     { 'f', "fragment",   Arg_parser::no  },
@@ -76,6 +78,7 @@ const Arg_parser::Option options[] = {
     { 'E', "height",     Arg_parser::yes  },
     { 'x', "max-size",   Arg_parser::yes  },
     { 'g', "no-default-fg", Arg_parser::no  },
+    { 'A', "line-append",   Arg_parser::yes  },
 
     {  0,  nullptr,           Arg_parser::no  }
 };
@@ -93,6 +96,8 @@ CmdLineOptions::CmdLineOptions( const int argc, const char *argv[] ):
     opt_cp437(false),
     opt_asciiBin(false),
     opt_asciiTundra(false),
+    teeMode(false),
+    appendMode(false),
     opt_omit_trailing_cr(false),
     opt_omit_version_info(false),
     opt_ignoreClear(true),
@@ -150,6 +155,12 @@ void CmdLineOptions::parseRuntimeOptions( const int argc, const char *argv[], bo
             opt_anchors = true;
             if ( arg=="self" ) opt_funny_anchors=true;
             break;
+        case 'b':
+            appendMode = true;
+            break;
+        case 'n':
+            teeMode = true;
+            break;
         case 'B':
             outputType = ansifilter::BBCODE;
             break;
@@ -266,7 +277,9 @@ void CmdLineOptions::parseRuntimeOptions( const int argc, const char *argv[], bo
         case 'E':
             height=arg;
             break;
-
+        case 'A':
+            lineAppendage = arg;
+            break;
         case 'x': {
             StringTools::str2num<off_t> ( maxFileSize, arg, std::dec );
             switch (arg[arg.size()-1]) {
@@ -332,6 +345,11 @@ string CmdLineOptions::getDirName(const string & path)
     return (dirNameLength==string::npos)?string():path.substr(0, dirNameLength+1);
 }
 
+string CmdLineOptions::getLineAppendage() {
+    return lineAppendage;
+}
+
+
 bool CmdLineOptions::printVersion()const
 {
     return opt_version;
@@ -508,3 +526,13 @@ off_t CmdLineOptions::getMaxFileSize() const
 {
     return maxFileSize;
 }
+
+bool CmdLineOptions::getTeeMode() const
+{
+    return teeMode;
+}
+
+bool CmdLineOptions::getAppendMode() const
+{
+    return appendMode;
+}
