@@ -86,6 +86,9 @@ public:
     /** \return output file suffix */
     string getOutFileSuffix() const;
 
+    /** \return Line append string */
+    string getLineAppendage();
+
     /** \return Output file format */
     ansifilter::OutputType getOutputType() const;
 
@@ -164,6 +167,9 @@ public:
     /** \return Allowed input file size */
     off_t getMaxFileSize() const;
 
+    bool getTeeMode() const;
+    bool getAppendMode() const;
+
 private:
     ansifilter::OutputType outputType;
 
@@ -178,6 +184,8 @@ private:
     bool opt_cp437;
     bool opt_asciiBin;
     bool opt_asciiTundra;
+    bool teeMode;
+    bool appendMode;
 
     bool opt_omit_trailing_cr;
     bool opt_omit_version_info;
@@ -200,6 +208,7 @@ private:
     string colorMapPath;
     string width;
     string height;
+    string lineAppendage;
 
     int wrapLineLen;
     int asciiArtWidth;
