@@ -1,7 +1,7 @@
 /***************************************************************************
                       codegenerator.cpp  -  description
                              -------------------
-    copyright            : (C) 2007-2024 by Andre Simon
+    copyright            : (C) 2007-2025 by Andre Simon
     email                : a.simon@mailbox.org
  ***************************************************************************/
 
@@ -198,6 +198,10 @@ void CodeGenerator::setTitle(const string & title)
     }
 }
 
+void CodeGenerator::setLineAppendage(const string& a) {
+  lineAppendage = a;
+}
+
 string CodeGenerator::getTitle()
 {
     return docTitle;
@@ -374,6 +378,8 @@ ParseError CodeGenerator::generateFileFromString (const string &sourceStr,
 }
 
 
+
+
 bool CodeGenerator::printDynamicStyleFile ( const string &outPath )
 {
     return true;
@@ -1364,6 +1370,7 @@ void CodeGenerator::printNewLine(bool eof) {
         lineStr = lineStr.substr(0, lineBuf.tellp());
     }
     *out << lineStr;
+    *out << lineAppendage;
     *out << newLineTag;
 
     lineBuf.clear();
