@@ -2,7 +2,7 @@
                           htmlgenerator.h  -  description
                              -------------------
 
-    copyright            : (C) 2007 by Andre Simon
+    copyright            : (C) 2007-2024 by Andre Simon
     email                : a.simon@mailbox.org
  ***************************************************************************/
 
@@ -28,11 +28,12 @@ along with ANSIFilter.  If not, see <http://www.gnu.org/licenses/>.
 #define HTMLGENERATOR_H
 
 #include "codegenerator.h"
+#include <string_view>
 
 namespace ansifilter
 {
 
-    
+
 /**
    \brief This class generates HTML.
 
@@ -60,31 +61,29 @@ protected:
     string getGeneratorComment();
 
     void insertLineNumber ();
-    
-    bool printDynamicStyleFile ( const string &outPath );
 
+    bool printDynamicStyleFile ( const string &outPath );
 
 private:
 
     string getOpenTag();
     string getCloseTag();
 
-    /** Print document header
-    */
+    /** Print document header */
     string getHeader();
 
-    /** Print document body*/
+    /** Print document body */
     void printBody();
 
-    /** Print document footer*/
+    /** Print document footer */
     string getFooter();
 
-    /** \return escaped character*/
+    /** \return escaped character */
     virtual string maskCharacter(unsigned char );
     virtual string maskCP437Character(unsigned char);
-    
-};
 
+    virtual string getHyperlink(std::string_view uri, std::string_view txt);
+};
 
 }
 
