@@ -2,7 +2,7 @@
                           main.cpp  -  description
                              -------------------
 
-    copyright            : (C) 2007-2024 by Andre Simon
+    copyright            : (C) 2007-2025 by Andre Simon
     email                : a.simon@mailbox.org
 
    Highlight is a universal source code to HTML converter. Syntax highlighting
@@ -30,7 +30,6 @@ along with ANSIFilter.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <memory>
 #include "main.h"
-#include "codegenerator.h"
 #include "platform_fs.h"
 
 using std::cout;
@@ -43,7 +42,7 @@ void ANSIFilterApp::printVersionInfo()
 {
     cout << "\n ansifilter version "
          << Info::getVersion()
-         << "\n Copyright (C) 2007-2024 Andre Simon <a dot simon at mailbox.org>"
+         << "\n Copyright (C) 2007-2025 Andre Simon <a dot simon at mailbox.org>"
          << "\n\n Argparser class"
          << "\n Copyright (C) 2006-2008 Antonio Diaz Diaz <ant_diaz at teleline.es>"
          << "\n\n This software is released under the terms of the GNU General "
@@ -60,6 +59,8 @@ void ANSIFilterApp::printHelp()
     cout << "  -i, --input=<file>     Name of input file (default stdin)\n";
     cout << "  -o, --output=<file>    Name of output file (default stdout)\n";
     cout << "  -O, --outdir=<dir>     Name of output directory\n";
+    cout << "  -n, --tee              Copy stdin to stdout and write filtered output to file\n";
+    cout << "  -b, --append           Append to output file (use with --tee)\n";
     cout << "  -t, --tail             Continue reading after end-of-file (like tail -f)\n";
     cout << "  -x, --max-size=<size>  Set maximum input file size\n";
     cout << "                         (examples: 512M, 1G; default: 256M)\n";
@@ -81,6 +82,7 @@ void ANSIFilterApp::printHelp()
     cout << "  -F, --font=<font>      Set HTML/RTF/SVG font face\n";
     cout << "  -k, --ignore-clear(=0) Do not adhere to clear (ESC K) commands (default: true)\n";
     cout << "  -c, --ignore-csi       Do not adhere to CSI commands (useful for UTF-8 input)\n";
+    cout << "  -A, --line-append=<s>  Output string after each output line\n";
     cout << "  -l, --line-numbers     Print line numbers in output file\n";
     cout << "  -m, --map=<path>       Read color mapping file (see README)\n";
     cout << "  -r, --style-ref=<rf>   Set HTML/TeX/LaTeX/SVG stylesheet path\n";
@@ -117,6 +119,32 @@ void ANSIFilterApp::printHelp()
     cout << "For updates see " << Info::getWebsite()<< "\n";
 }
 
+void ANSIFilterApp::setGeneratorProperties(ansifilter::CodeGenerator* generator, const CmdLineOptions& options, const string& title)
+{
+    generator->setTitle(title);
+    generator->setEncoding(options.getEncoding());
+    generator->setFragmentCode(options.fragmentOutput());
+    generator->setPlainOutput(options.plainOutput());
+    generator->setContinueReading(options.ignoreInputEOF());
+    generator->setFont(options.getFont());
+    generator->setFontSize(options.getFontSize());
+    generator->setStyleSheet(options.getStyleSheetPath());
+    generator->setPreformatting(ansifilter::WRAP_SIMPLE, options.getWrapLineLength());
+    generator->setShowLineNumbers(options.showLineNumbers());
+    generator->setWrapNoNumbers(!options.wrapNoNumbers());
+    generator->setAddAnchors(options.addAnchors(), options.addFunnyAnchors());
+    generator->setParseCodePage437(options.parseCP437());
+    generator->setParseAsciiBin(options.parseAsciiBin());
+    generator->setParseAsciiTundra(options.parseAsciiTundra());
+    generator->setIgnoreClearSeq(options.ignoreClearSeq());
+    generator->setIgnoreCSISeq(options.ignoreCSISeq());
+    generator->setApplyDynStyles(options.applyDynStyles());
+    generator->setAsciiArtSize(options.getAsciiArtWidth(), options.getAsciiArtHeight());
+    generator->setOmitTrailingCR(options.omitTrailingCR());
+    generator->setOmitVersionInfo(options.omitVersionInfo());
+    generator->setSVGSize ( options.getWidth(), options.getHeight() );
+}
+
 int ANSIFilterApp::run( const int argc, const char *argv[] )
 {
 
@@ -132,9 +160,57 @@ int ANSIFilterApp::run( const int argc, const char *argv[] )
         return EXIT_SUCCESS;
     }
 
-    const  vector <string> inFileList=options.getInputFileNames();
     unique_ptr<ansifilter::CodeGenerator> generator(ansifilter::CodeGenerator::getInstance(options.getOutputType()));
 
+    if (options.getTeeMode()) {
+
+
+        if (options.getOutputType() != ansifilter::TEXT) {
+            cerr << "ansifilter: --tee mode allows only text output" << endl;
+            return EXIT_FAILURE;
+        }
+
+        string outFilePath = options.getSingleOutFilename();
+        if (outFilePath.empty()) {
+            cerr << "ansifilter: --tee mode requires an output file specified with -o" << endl;
+            return EXIT_FAILURE;
+        }
+
+        if (!options.omitDefaultForegroundColor()) {
+            generator->setDefaultForegroundColor();
+        }
+
+        string mapPath = options.getMapPath();
+        if (!generator->setColorMap(mapPath)){
+            std::cerr <<"could not read map file: " << mapPath << "\n";
+            return EXIT_FAILURE;
+        }
+
+        setGeneratorProperties(generator.get(), options, options.getDocumentTitle());
+
+        std::ofstream outFile;
+        if (options.getAppendMode()) {
+            outFile.open(outFilePath.c_str(), std::ios_base::app);
+        } else {
+            outFile.open(outFilePath.c_str());
+        }
+
+        if (!outFile.is_open()) {
+            cerr << "could not write output: " << outFilePath << endl;
+            return EXIT_FAILURE;
+        }
+
+        string buffer;
+        while (getline(cin, buffer)) {
+            cout << buffer << endl;
+            outFile << generator->generateString(buffer);
+        }
+
+        return EXIT_SUCCESS;
+    }
+
+    const  vector <string> inFileList=options.getInputFileNames();
+
     string outDirectory = options.getOutDirectory();
 
     unsigned int fileCount=inFileList.size(), i=0;
@@ -170,33 +246,9 @@ int ANSIFilterApp::run( const int argc, const char *argv[] )
             return EXIT_FAILURE;
         }
 
-        generator->setTitle(options.getDocumentTitle().empty()?
-                            inFileList[i]:options.getDocumentTitle());
+        setGeneratorProperties(generator.get(), options, options.getDocumentTitle().empty() ? inFileList[i] : options.getDocumentTitle());
 
-        generator->setEncoding(options.getEncoding());
-        generator->setFragmentCode(options.fragmentOutput());
-        generator->setPlainOutput(options.plainOutput());
-        generator->setContinueReading(options.ignoreInputEOF());
-        generator->setFont(options.getFont());
-        generator->setFontSize(options.getFontSize());
-        generator->setStyleSheet(options.getStyleSheetPath());
-        generator->setPreformatting(ansifilter::WRAP_SIMPLE, options.getWrapLineLength());
-        generator->setShowLineNumbers(options.showLineNumbers());
-        generator->setWrapNoNumbers(!options.wrapNoNumbers());
-        generator->setAddAnchors(options.addAnchors(), options.addFunnyAnchors());
-        generator->setParseCodePage437(options.parseCP437());
-        generator->setParseAsciiBin(options.parseAsciiBin());
-        generator->setParseAsciiTundra(options.parseAsciiTundra());
-        generator->setIgnoreClearSeq(options.ignoreClearSeq());
-        generator->setIgnoreCSISeq(options.ignoreCSISeq());
-
-        generator->setApplyDynStyles(options.applyDynStyles());
-
-        generator->setAsciiArtSize(options.getAsciiArtWidth(), options.getAsciiArtHeight());
-        generator->setOmitTrailingCR(options.omitTrailingCR());
-        generator->setOmitVersionInfo(options.omitVersionInfo());
-
-        generator->setSVGSize ( options.getWidth(), options.getHeight() );
+        generator->setLineAppendage ( options.getLineAppendage() );
 
         ansifilter::ParseError error = generator->generateFile(inFileList[i], outFilePath);
 
