@@ -18,7 +18,6 @@ along with ANSIFilter.  If not, see <http://www.gnu.org/licenses/>.
 #ifndef ANSIFILTER_APP
 #define ANSIFILTER_APP
 
-
 #include <iostream>
 #include <fstream>
 #include <string>
@@ -29,6 +28,7 @@ along with ANSIFilter.  If not, see <http://www.gnu.org/licenses/>.
 
 #include "cmdlineoptions.h"
 #include "version.h"
+#include "codegenerator.h"
 
 /// Main application class of the command line interface
 
@@ -51,6 +51,7 @@ private:
 
     void printVersionInfo();
     void printHelp();
+    void setGeneratorProperties(ansifilter::CodeGenerator* generator, const CmdLineOptions& options, const std::string& title);
 
 };
 
