@@ -1,7 +1,7 @@
 /***************************************************************************
                         mydialog.h  -  description
                              -------------------
-    copyright            : (C) 2007-2020 by Andre Simon
+    copyright            : (C) 2007-2025 by Andre Simon
     email                : andre.simon1@gmx.de
  ***************************************************************************/
 
@@ -26,7 +26,6 @@ along with ANSIFilter.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <QtGlobal>
 
-
 #ifdef Q_OS_WIN
 #include <windows.h>
 #endif
@@ -55,40 +54,38 @@ MyDialog::MyDialog(QWidget * parent, Qt::WindowFlags f):QDialog(parent, f)
 {
 
 #ifdef Q_OS_WIN
-// https://forum.qt.io/topic/101391/windows-10-dark-theme/
-if (QSysInfo::productVersion()=="10") {
-    QSettings settings("HKEY_CURRENT_USER\\Software\\Microsoft\\Windows\\CurrentVersion\\Themes\\Personalize",QSettings::NativeFormat);
-    if(settings.value("AppsUseLightTheme")==0){
-        qApp->setStyle(QStyleFactory::create("Fusion"));
-        QPalette darkPalette;
-        QColor darkColor = QColor(45,45,45);
-        QColor disabledColor = QColor(127,127,127);
-        darkPalette.setColor(QPalette::Window, darkColor);
-        darkPalette.setColor(QPalette::WindowText, Qt::white);
-        darkPalette.setColor(QPalette::Base, QColor(18,18,18));
-        darkPalette.setColor(QPalette::AlternateBase, darkColor);
-        darkPalette.setColor(QPalette::ToolTipBase, Qt::white);
-        darkPalette.setColor(QPalette::ToolTipText, Qt::white);
-        darkPalette.setColor(QPalette::Text, Qt::white);
-        darkPalette.setColor(QPalette::Disabled, QPalette::Text, disabledColor);
-        darkPalette.setColor(QPalette::Button, darkColor);
-        darkPalette.setColor(QPalette::ButtonText, Qt::white);
-        darkPalette.setColor(QPalette::Disabled, QPalette::ButtonText, disabledColor);
-        darkPalette.setColor(QPalette::BrightText, Qt::red);
-        darkPalette.setColor(QPalette::Link, QColor(42, 130, 218));
+    // https://forum.qt.io/topic/101391/windows-10-dark-theme/
+    if (QSysInfo::productVersion()=="10") {
+        QSettings settings("HKEY_CURRENT_USER\\Software\\Microsoft\\Windows\\CurrentVersion\\Themes\\Personalize",QSettings::NativeFormat);
+        if(settings.value("AppsUseLightTheme")==0){
+            qApp->setStyle(QStyleFactory::create("Fusion"));
+            QPalette darkPalette;
+            QColor darkColor = QColor(45,45,45);
+            QColor disabledColor = QColor(127,127,127);
+            darkPalette.setColor(QPalette::Window, darkColor);
+            darkPalette.setColor(QPalette::WindowText, Qt::white);
+            darkPalette.setColor(QPalette::Base, QColor(18,18,18));
+            darkPalette.setColor(QPalette::AlternateBase, darkColor);
+            darkPalette.setColor(QPalette::ToolTipBase, Qt::white);
+            darkPalette.setColor(QPalette::ToolTipText, Qt::white);
+            darkPalette.setColor(QPalette::Text, Qt::white);
+            darkPalette.setColor(QPalette::Disabled, QPalette::Text, disabledColor);
+            darkPalette.setColor(QPalette::Button, darkColor);
+            darkPalette.setColor(QPalette::ButtonText, Qt::white);
+            darkPalette.setColor(QPalette::Disabled, QPalette::ButtonText, disabledColor);
+            darkPalette.setColor(QPalette::BrightText, Qt::red);
+            darkPalette.setColor(QPalette::Link, QColor(42, 130, 218));
 
-        darkPalette.setColor(QPalette::Highlight, QColor(153, 153, 153));
-        darkPalette.setColor(QPalette::HighlightedText, Qt::black);
-        darkPalette.setColor(QPalette::Disabled, QPalette::HighlightedText, disabledColor);
+            darkPalette.setColor(QPalette::Highlight, QColor(153, 153, 153));
+            darkPalette.setColor(QPalette::HighlightedText, Qt::black);
+            darkPalette.setColor(QPalette::Disabled, QPalette::HighlightedText, disabledColor);
 
-        qApp->setPalette(darkPalette);
-        qApp->setStyleSheet("QToolTip { color: #ffffff; background-color: #404040; border: 1px solid white; }");
+            qApp->setPalette(darkPalette);
+            qApp->setStyleSheet("QToolTip { color: #ffffff; background-color: #404040; border: 1px solid white; }");
+        }
     }
-}
 #endif
 
-
-
     dlg.setupUi(this);
     QSettings settings("andre-simon.de", "ansifilter-gui");
     settings.beginGroup("format");
@@ -322,20 +319,17 @@ void MyDialog::on_pbSaveAs_clicked()
 
     unique_ptr<ansifilter::CodeGenerator> generator(ansifilter::CodeGenerator::getInstance(getOutputType()));
     generator->setDefaultForegroundColor();
+
     generator->setTitle( (dlg.leTitle->text().isEmpty()? title : dlg.leTitle->text()).toStdString());
     generator->setEncoding(dlg.comboEncoding->currentText().toStdString());
     generator->setFragmentCode(dlg.cbFragment->isChecked());
     generator->setPlainOutput(dlg.cbIgnoreSequences->isChecked());
     generator->setOmitVersionInfo(dlg.cbOmitVersion->isChecked());
-
     generator->setIgnoreClearSeq(dlg.cbIgnClearSeq->isChecked());
     generator->setIgnoreCSISeq(dlg.cbIgnCSISeq->isChecked());
-
     generator->setApplyDynStyles(dlg.cbDeriveStyles->isChecked());
-
     generator->setSVGSize(dlg.leSvgWidth->text().toStdString(), dlg.leSvgHeight->text().toStdString());
 
-
     if (dlg.leStyleFile->text().isEmpty() && dlg.cbDeriveStyles->isChecked()&& (dlg.comboFormat->currentIndex()==1 || dlg.comboFormat->currentIndex()==7) )
         dlg.leStyleFile->setText("derived_styles.css");
 
@@ -393,7 +387,6 @@ void MyDialog::on_pbSaveAs_clicked()
         }
     }
     this->setCursor(Qt::ArrowCursor);
-
 }
 
 
@@ -495,7 +488,7 @@ void MyDialog::on_pbAbout_clicked()
     QMessageBox::about(this,
                        "ANSIFilter Information",
                        QString("ANSIFilter GUI %1\n"
-                       "(c) 2007-2023 Andre Simon\n\n"
+                       "(c) 2007-2025 Andre Simon\n\n"
                        "Built with Qt version %2\n\n"
                        "Released under the terms of the GNU GPL license.\n\n"
                        "%3\n"
@@ -514,23 +507,26 @@ void MyDialog::on_cbParseAsciiArt_clicked()
     showFile();
 }
 
-
 void MyDialog::on_sbWidth_valueChanged(int i)
 {
     showFile();
 }
+
 void MyDialog::on_sbHeight_valueChanged(int i)
 {
     showFile();
 }
+
 void MyDialog::on_comboAnsiFormat_currentIndexChanged(int idx)
 {
     showFile();
 }
+
 void MyDialog::on_comboFont_currentIndexChanged(int idx)
 {
     showFile();
 }
+
 void MyDialog::on_comboEncoding_currentIndexChanged(int idx)
 {
     showFile();
@@ -566,3 +562,15 @@ QString MyDialog::getWindowsShortPath(const QString & path){
 #endif
     return shortPath;
 }
+
+void MyDialog::on_pbToggleView_clicked()
+{
+    if (dlg.groupBox->isVisible()) {
+        dlg.groupBox->hide();
+        dlg.pbToggleView->setText("Show Options");
+    } else {
+        dlg.groupBox->show();
+        dlg.pbToggleView->setText("Hide Options");
+    }
+
+}
